OrderApi

Struct OrderApi 

pub struct OrderApi<'a> { /* private fields */ }
User-facing order creation API.

Implementations

Source

impl<'a> OrderApi<'a>

pub fn generate_client_order_id(&self) -> ClientOrderId

Generates a new client order ID.

Panics

Panics if the order factory is already mutably borrowed.

pub fn generate_order_list_id(&self) -> OrderListId

Generates a new order list ID.

Panics

Panics if the order factory is already mutably borrowed.

pub fn market( &self, instrument_id: InstrumentId, order_side: OrderSide, quantity: Quantity, time_in_force: Option<TimeInForce>, reduce_only: Option<bool>, quote_quantity: Option<bool>, exec_algorithm_id: Option<ExecAlgorithmId>, exec_algorithm_params: Option<IndexMap<Ustr, Ustr>>, tags: Option<Vec<Ustr>>, client_order_id: Option<ClientOrderId>, ) -> OrderAny

Creates a new market order.

Panics

Panics if the order parameters fail validation or the order factory is already mutably borrowed.

pub fn limit( &self, instrument_id: InstrumentId, order_side: OrderSide, quantity: Quantity, price: Price, time_in_force: Option<TimeInForce>, expire_time: Option<UnixNanos>, post_only: Option<bool>, reduce_only: Option<bool>, quote_quantity: Option<bool>, display_qty: Option<Quantity>, emulation_trigger: Option<TriggerType>, trigger_instrument_id: Option<InstrumentId>, exec_algorithm_id: Option<ExecAlgorithmId>, exec_algorithm_params: Option<IndexMap<Ustr, Ustr>>, tags: Option<Vec<Ustr>>, client_order_id: Option<ClientOrderId>, ) -> OrderAny

Creates a new limit order.

Panics

Panics if the order parameters fail validation or the order factory is already mutably borrowed.

pub fn stop_market( &self, instrument_id: InstrumentId, order_side: OrderSide, quantity: Quantity, trigger_price: Price, trigger_type: Option<TriggerType>, time_in_force: Option<TimeInForce>, expire_time: Option<UnixNanos>, reduce_only: Option<bool>, quote_quantity: Option<bool>, display_qty: Option<Quantity>, emulation_trigger: Option<TriggerType>, trigger_instrument_id: Option<InstrumentId>, exec_algorithm_id: Option<ExecAlgorithmId>, exec_algorithm_params: Option<IndexMap<Ustr, Ustr>>, tags: Option<Vec<Ustr>>, client_order_id: Option<ClientOrderId>, ) -> OrderAny

Creates a new stop-market order.

Panics

Panics if the order parameters fail validation or the order factory is already mutably borrowed.

pub fn stop_limit( &self, instrument_id: InstrumentId, order_side: OrderSide, quantity: Quantity, price: Price, trigger_price: Price, trigger_type: Option<TriggerType>, time_in_force: Option<TimeInForce>, expire_time: Option<UnixNanos>, post_only: Option<bool>, reduce_only: Option<bool>, quote_quantity: Option<bool>, display_qty: Option<Quantity>, emulation_trigger: Option<TriggerType>, trigger_instrument_id: Option<InstrumentId>, exec_algorithm_id: Option<ExecAlgorithmId>, exec_algorithm_params: Option<IndexMap<Ustr, Ustr>>, tags: Option<Vec<Ustr>>, client_order_id: Option<ClientOrderId>, ) -> OrderAny

Creates a new stop-limit order.

Panics

Panics if the order parameters fail validation or the order factory is already mutably borrowed.

pub fn market_to_limit( &self, instrument_id: InstrumentId, order_side: OrderSide, quantity: Quantity, time_in_force: Option<TimeInForce>, expire_time: Option<UnixNanos>, reduce_only: Option<bool>, quote_quantity: Option<bool>, display_qty: Option<Quantity>, exec_algorithm_id: Option<ExecAlgorithmId>, exec_algorithm_params: Option<IndexMap<Ustr, Ustr>>, tags: Option<Vec<Ustr>>, client_order_id: Option<ClientOrderId>, ) -> OrderAny

Creates a new market-to-limit order.

Panics

Panics if the order parameters fail validation or the order factory is already mutably borrowed.

pub fn market_if_touched( &self, instrument_id: InstrumentId, order_side: OrderSide, quantity: Quantity, trigger_price: Price, trigger_type: Option<TriggerType>, time_in_force: Option<TimeInForce>, expire_time: Option<UnixNanos>, reduce_only: Option<bool>, quote_quantity: Option<bool>, emulation_trigger: Option<TriggerType>, trigger_instrument_id: Option<InstrumentId>, exec_algorithm_id: Option<ExecAlgorithmId>, exec_algorithm_params: Option<IndexMap<Ustr, Ustr>>, tags: Option<Vec<Ustr>>, client_order_id: Option<ClientOrderId>, ) -> OrderAny

Creates a new market-if-touched order.

Panics

Panics if the order parameters fail validation or the order factory is already mutably borrowed.

pub fn limit_if_touched( &self, instrument_id: InstrumentId, order_side: OrderSide, quantity: Quantity, price: Price, trigger_price: Price, trigger_type: Option<TriggerType>, time_in_force: Option<TimeInForce>, expire_time: Option<UnixNanos>, post_only: Option<bool>, reduce_only: Option<bool>, quote_quantity: Option<bool>, display_qty: Option<Quantity>, emulation_trigger: Option<TriggerType>, trigger_instrument_id: Option<InstrumentId>, exec_algorithm_id: Option<ExecAlgorithmId>, exec_algorithm_params: Option<IndexMap<Ustr, Ustr>>, tags: Option<Vec<Ustr>>, client_order_id: Option<ClientOrderId>, ) -> OrderAny

Creates a new limit-if-touched order.

Panics

Panics if the order parameters fail validation or the order factory is already mutably borrowed.

pub fn trailing_stop_market( &self, instrument_id: InstrumentId, order_side: OrderSide, quantity: Quantity, trailing_offset: Decimal, trailing_offset_type: Option<TrailingOffsetType>, activation_price: Option<Price>, trigger_price: Option<Price>, trigger_type: Option<TriggerType>, time_in_force: Option<TimeInForce>, expire_time: Option<UnixNanos>, reduce_only: Option<bool>, quote_quantity: Option<bool>, display_qty: Option<Quantity>, emulation_trigger: Option<TriggerType>, trigger_instrument_id: Option<InstrumentId>, exec_algorithm_id: Option<ExecAlgorithmId>, exec_algorithm_params: Option<IndexMap<Ustr, Ustr>>, tags: Option<Vec<Ustr>>, client_order_id: Option<ClientOrderId>, ) -> OrderAny

Creates a new trailing-stop-market order.

Panics

Panics if the order parameters fail validation or the order factory is already mutably borrowed.

pub fn trailing_stop_limit( &self, instrument_id: InstrumentId, order_side: OrderSide, quantity: Quantity, price: Price, limit_offset: Decimal, trailing_offset: Decimal, trailing_offset_type: Option<TrailingOffsetType>, activation_price: Option<Price>, trigger_price: Option<Price>, trigger_type: Option<TriggerType>, time_in_force: Option<TimeInForce>, expire_time: Option<UnixNanos>, post_only: Option<bool>, reduce_only: Option<bool>, quote_quantity: Option<bool>, display_qty: Option<Quantity>, emulation_trigger: Option<TriggerType>, trigger_instrument_id: Option<InstrumentId>, exec_algorithm_id: Option<ExecAlgorithmId>, exec_algorithm_params: Option<IndexMap<Ustr, Ustr>>, tags: Option<Vec<Ustr>>, client_order_id: Option<ClientOrderId>, ) -> OrderAny

Creates a new trailing-stop-limit order.

Panics

Panics if the order parameters fail validation or the order factory is already mutably borrowed.

pub fn create_list( &self, orders: &mut [OrderAny], ts_init: UnixNanos, ) -> OrderList

Creates a new order list from the given orders.

Panics

Panics if the list parameters fail validation or the order factory is already mutably borrowed.

pub fn bracket<'f1>(&'f1 self) -> OrderApiBracketBuilder<'a, 'f1>

Creates a bracket order with an entry order and attached take-profit and stop-loss legs.

Panics

Panics if the bracket parameters fail validation or the order factory is already mutably borrowed.